ISOBox class

Represents an ISO box.

Available extensions

Constructors

ISOBox(bool isRootFileBox, int boxSize, String type, int headerOffset, int dataOffset, int? fullBoxInt32)

Properties

boxSize int
The size of the box.
final
dataOffset int
The offset of the data in the file.
final
dataSize int
The size of the data in the box.
no setter
flags int
no setter
fullBoxInt32 int?
The full box data.
final
hashCode int
The hash code for this object.
no setterinherited
headerOffset int
The offset of the header in the file.
final
headerSize int
no setter
index int
An optional index of the box when calling nextChild.
no setter
isRootFileBox bool
Whether the box is the root file box.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of the box.
final
version int
no setter

Methods

extractData(RandomAccessSource src) Future<Uint8List>
Extracts the data from the box.
getChildByTypePath(RandomAccessSource src, List<String> path, {bool isFullBoxCallback(String type)?}) Future<ISOBox?>

Available on ISOBox, provided by the ISOBoxExtension extension

Returns a child box by a given type path. isFullBoxCallback is a callback to determine if a box is a full box.
getDirectChild(RandomAccessSource src, {bool isFullBoxCallback(String type)?, bool filter(ISOBox box)?}) Future<ISOBox?>

Available on ISOBox, provided by the ISOBoxExtension extension

Return a direct child box by a given async filter. filter is a callback to filter boxes. isFullBoxCallback is a callback to determine if a box is a full box.
getDirectChildByAsyncFilter(RandomAccessSource src, Future<bool> filter(ISOBox box), {bool isFullBoxCallback(String type)?}) Future<ISOBox?>

Available on ISOBox, provided by the ISOBoxExtension extension

Return a direct child box by a given async filter. filter is a callback to filter boxes. isFullBoxCallback is a callback to determine if a box is a full box.
getDirectChildByTypes(RandomAccessSource src, Set<String> types, {bool isFullBoxCallback(String type)?}) Future<ISOBox?>

Available on ISOBox, provided by the ISOBoxExtension extension

Returns a direct child box by given types. An empty types set will return the first child box. isFullBoxCallback is a callback to determine if a box is a full box.
getDirectChildren(RandomAccessSource src, {bool isFullBoxCallback(String type)?, bool filter(ISOBox box)?}) Future<List<ISOBox>>

Available on ISOBox, provided by the ISOBoxExtension extension

Return a list of direct children boxes by a given filter. filter is a callback to filter boxes. isFullBoxCallback is a callback to determine if a box is a full box.
getDirectChildrenByAsyncFilter(RandomAccessSource src, Future<bool> filter(ISOBox box), {bool isFullBoxCallback(String type)?}) Future<List<ISOBox>>

Available on ISOBox, provided by the ISOBoxExtension extension

Return a list of direct children boxes by a given async filter. isFullBoxCallback is a callback to determine if a box is a full box.
getDirectChildrenByTypes(RandomAccessSource src, Set<String> types, {bool isFullBoxCallback(String type)?}) Future<List<ISOBox>>

Available on ISOBox, provided by the ISOBoxExtension extension

Returns a list of direct children by given types. An empty types set will return all child boxes. isFullBoxCallback is a callback to determine if a box is a full box.
getFullBoxInfo() ISOFullBoxInfo?
Returns the full box info.
nextChild(RandomAccessSource src, {bool isFullBoxCallback(String type)?, int? index, int skipOffset = 0}) Future<ISOBox?>
Returns the next child box. If this box is not a container, returns null. src is the source to read from. isFullBoxCallback is a callback to determine if a box is a full box. index is an optional index to set on the returned box. skipOffset is an optional offset to skip before reading the next child box.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseFtyp(RandomAccessSource src) Future<ISOBoxFtypData?>

Available on ISOBox, provided by the ISOBoxFtypExtension extension

resetPosition(RandomAccessSource src) Future<void>
This calls seekInContent with an offset of 0, effectively resetting the position to the start of the box data.
seekInContent(RandomAccessSource src, int offset) Future<void>
Sets the internal file position to the specified offset within the content of the box.
toBytes(RandomAccessSource src) Future<Uint8List>
Returns the box as bytes. This includes the header and the data.
toDict() Map<String, dynamic>
Converts the box to a dictionary.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createRootBox() ISOBox
Creates a root ISOBox.